__version__ = "0.0.1"
from ._jwst_cosmic_cliffs import make_sample_data

__all__ = (
    "make_sample_data",
    )
